@@ -20,12 +20,15 @@
 #' @param type_check_msg When the `type_check=` fails, the string provided
 #' here will be printed as the error message. When `NULL`, a generic
 #' error message will be printed.
+#' @param null_allowed Are `NULL` values accepted for the right hand side of
+#' formulas?
 #' @inheritParams .select_to_varnames
 #'
 #' @export
 .formula_list_to_named_list <- function(x, data = NULL, var_info = NULL,
                                         arg_name = NULL, select_single = FALSE,
-                                        type_check = NULL, type_check_msg = NULL) {
+                                        type_check = NULL, type_check_msg = NULL,
+                                        null_allowed = TRUE) {
   # if NULL provided, return NULL ----------------------------------------------
   if (is.null(x)) {
     return(NULL)
@@ -54,18 +57,42 @@
                                 arg_name = arg_name,
                                 select_single = select_single,
                                 type_check = type_check,
-                                type_check_msg = type_check_msg) %>%
+                                type_check_msg = type_check_msg,
+                                null_allowed = null_allowed) %>%
         list()
     }
     else {
       .formula_select_error(arg_name = arg_name)
     }
+
+    .rhs_checks(x = named_list[i][[1]], arg_name = arg_name, type_check = type_check,
+                type_check_msg = type_check_msg, null_allowed = null_allowed)
   }
   named_list <- purrr::flatten(named_list)
 
   # removing duplicates (using the last one listed if variable occurs more than once)
   tokeep <- names(named_list) %>% rev() %>% {!duplicated(.)} %>% rev()
-  named_list[tokeep]
+  result <- named_list[tokeep]
+
+  if (isTRUE(select_single) && length(result) > 1) {
+    .select_single_error_msg(names(result), arg_name = arg_name)
+  }
+  result
+}
+
+.select_single_error_msg <- function(selected, arg_name) {
+  if (!rlang::is_empty(arg_name)) {
+    stringr::str_glue(
+      "Error in `{arg_name}=` argument--select only a single column. ",
+      "The following columns were selected, ",
+      "{paste(sQuote(selected), collapse = ', ')}") %>%
+      stop(call. = FALSE)
+  }
+  stringr::str_glue(
+    "Error in selector--select only a single column. ",
+    "The following columns were selected, ",
+    "{paste(sQuote(selected), collapse = ', ')}") %>%
+    stop(call. = FALSE)
 }
 
 .check_valid_input <- function(x, arg_name, type_check) {
@@ -83,7 +110,7 @@
           switch(rlang::is_string(x)) %||% as.character(deparse(x)),
           error = function(e) NULL
         ))
-      if (!is.null(x_string) && nchar(x_string) <= 50) {
+      if (!is.null(x_string) && length(x_string) == 1 && nchar(x_string) <= 50) {
         err_msg <-
           paste(
             err_msg,
@@ -99,9 +126,39 @@
   return(invisible())
 }
 
+# checking the type/class/NULL of the RHS of formula
+.rhs_checks <- function(x, arg_name,
+                        type_check, type_check_msg,
+                        null_allowed) {
+  purrr::imap(
+    x,
+    function(rhs, lhs) {
+      if (!null_allowed && is.null(rhs)){
+        stringr::str_glue(
+          "Error processing `{arg_name %||% ''}` argument for element '{lhs[[1]]}'. ",
+          "A NULL value is not allowed."
+        ) %>%
+          stop(call. = FALSE)
+      }
+
+      # check the type of RHS ------------------------------------------------------
+      if (!is.null(type_check) && !is.null(rhs) && !type_check(rhs)) {
+        stringr::str_glue(
+          "Error processing `{arg_name %||% ''}` argument for element '{lhs[[1]]}'. ",
+          type_check_msg %||% "The value passed is not the expected type/class."
+        ) %>%
+          stop(call. = FALSE)
+      }
+    }
+  )
+
+  return(invisible())
+}
+
 .single_formula_to_list <- function(x, data, var_info, arg_name,
-                                    select_single, type_check, type_check_msg) {
-  # for each formula extract lhs and rhs ---------------------------------
+                                    select_single, type_check, type_check_msg,
+                                    null_allowed) {
+  # for each formula extract lhs and rhs ---------------------------------------
   # checking the LHS is not empty
   f_lhs_quo <- .f_side_as_quo(x, "lhs")
   if (rlang::quo_is_null(f_lhs_quo)) f_lhs_quo <- rlang::expr(everything())
@@ -115,14 +172,8 @@
   # evaluate RHS of formula in the original formula environment
   rhs <- .f_side_as_quo(x, "rhs") %>% rlang::eval_tidy()
 
-  # check the type of RHS ------------------------------------------------------
-  if (!is.null(type_check) && !type_check(rhs)) {
-    type_check_msg %||%
-      stringr::str_glue(
-        "Error processing `{arg_name %||% ''}` argument for element '{lhs[[1]]}'. ",
-        "The value passed is not the expected type/class.") %>%
-      stop(call. = FALSE)
-  }
+  # checking if RHS is NULL ----------------------------------------------------
+
 
   # converting rhs and lhs into a named list
   purrr::map(lhs, ~ list(rhs) %>% rlang::set_names(.x)) %>%
@@ -197,11 +248,7 @@
 
   # assuring only a single column is selected
   if (select_single == TRUE && length(res) > 1) {
-    stop(stringr::str_glue(
-      "Error in `{arg_name}=` argument input--select only a single column. ",
-      "The following columns were selected, ",
-      "{paste(sQuote(res), collapse = ', ')}"
-    ), call. = FALSE)
+    .select_single_error_msg(res, arg_name = arg_name)
   }
 
   # if nothing is selected, return a NULL
